#
# spec file for package focuswriter
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2015 Graeme Gott <graeme@gottcode.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           focuswriter
Version:        1.8.5
Release:        1.1
Summary:        A fullscreen, distraction-free writing program
License:        GPL-3.0-or-later
Group:          Productivity/Office/Word Processor
URL:            https://gottcode.org/focuswriter
Source:         https://gottcode.org/focuswriter/%{name}-%{version}.tar.bz2
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  qt6-tools-linguist
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Linguist)
BuildRequires:  cmake(Qt6Multimedia)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6UiTools)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  pkgconfig(hunspell)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-io)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(zlib)
Requires(post): hicolor-icon-theme
Requires(post): update-desktop-files
Requires(postun):hicolor-icon-theme
Requires(postun):update-desktop-files

%description
A fullscreen, distraction-free writing program. You can customize your
environment by changing the font, colors, and background image to add
ambiance as you type. FocusWriter features an on-the-fly updating word
count, optional auto-save, optional daily goals, and an interface that
hides away to allow you to focus more clearly; additionally, when you open
the program your current work-in-progress will automatically load and
position you at the end of your document, so that you can immediately jump
back in.

%lang_package

%prep
%setup -q

%build
%cmake_qt6

%{qt6_build}

%install
%{qt6_install}

%suse_update_desktop_file %{name}

%find_lang %{name} --with-qt

%fdupes -s %{buildroot}

%files
%doc ChangeLog CREDITS README
%{_bindir}/%{name}
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/icons
%{_datadir}/%{name}/sounds
%{_datadir}/%{name}/themes
%{_datadir}/metainfo
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/focuswriter/symbols1500.dat

%files lang -f %{name}.lang
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/translations

%changelog
* Wed Jun 28 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.8.5:
  * FIXED: Unable to paste HTML into web browser
  * Translation Updates for: Russian, Turkish, Ukrainian
* Wed Jan 11 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.8.4:
  * FIXED: Did not ignore user input when force processing events
  * FIXED: Did not compile on macOS
  * FIXED: Did not compile on OS/2
  * Disabled typewriter sounds on OS/2
  * Replaced deprecated code
* Tue Sep 27 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.3:
  Bug Fixes:
  * FIXED: Did not play sound effect when pressing enter
  * FIXED: Played sound effect when opening files
  * FIXED: Missing version number
  Translation Updates:
  * Dutch
* Thu Sep 15 2022 Christophe Giboudeaux <christophe@krop.fr>
- Spec cleanup
- Use 'cmake()' style BuildRequires and Qt6 build macros to
  fix build on Leap 15.4
* Fri Sep  2 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.2:
  Bug Fixes:
  * FIXED: Could not change language in portable mode
  * FIXED: Crashed during paste from context menu
  * FIXED: First line indent was lost on empty paragraphs
  Code Improvements:
  * Always write RTF as Latin1
  * Replaced ICU with iconv
  * Improved Linux deployment
  Translation Updates:
  * German, Korean, Portuguese (Brazil), Russian, Swedish
* Mon Jul 11 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.1:
  * Always write plain text as UTF-8.
  * Always write RTF as codepage 1252.
  * Replaced QTextCodec with ICU.
  * Translation updates: Estonian, German.
* Mon Jul 11 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.0:
  * FIXED: Lines were randomly duplicated in ODT.
  * FIXED: Did not read text from lists in ODT.
  * FIXED: Formatting was lost when restoring untitled documents from cache.
  * FIXED: Loading headings caused document to shift vertically.
  * FIXED: Timers did not show countdown in tooltip.
  * FIXED: Sometimes could not remove dictionaries.
  * Only restore changed files from cache.
  * Refactored code.
  * Removed XPM icon.
  * Switched to Qt 6.
  * Updated Unicode symbols database.
  * Updated Windows dictionaries.
  * Translation updates
* Wed Apr 22 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.7.6:
  * FIXED: Did not load locales with underscores.
  * FIXED: Compile failure due to missing header.
  * Translation updates: Slovenian, Swedish, Turkish.
* Tue Feb 25 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.7.5:
  * Updated Windows dictionaries.
  * Updated Windows deployment.
  * Translation updates: Ukrainian.
* Fri Jan 17 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.7.4:
  * FIXED: Daily progress did not show star background with some themes.
  * Replaced deprecated code.
  * Translations: Catalan, Swedish.
* Tue Aug 20 2019 mvetter@suse.com
- Update to 1.7.3:
  * FIXED: Was not loading KDE icon theme.
  * FIXED: Headings menu was incorrectly shown in German.
  * Replaced deprecated code.
  * Translations: Friulian, German, Korean.
* Tue Mar 12 2019 Martin Pluskal <mpluskal@suse.com>
- Update Qt dependencies
* Mon Mar 11 2019 mvetter@suse.com
- Update to 1.7.2:
  * FIXED: Minimum sizes for page counts were too high.
  * FIXED: Window icon didn't work in Wayland.
  * Require Qt 5.9.
  * Improved loading locales.
  * Translation updates: Friulian, Korean.
* Sat Dec 22 2018 Michael Vetter <mvetter@suse.com>
- Update to 1.7.1:
  * FIXED: Did not launch when incorrect lock file was found.
* Sat Dec 15 2018 Michael Vetter <mvetter@suse.com>
- Update to 1.7.0:
  * FIXED: Daily progress percentages were not locale aware.
  * FIXED: Scene list text was incorrect with Qt 5.12
  * Show current streak for previous day.
  * Improved detection of running instance.
  * Updated included hunspell.
  * Updated dictionaries.
  * Translation updates: Czech, Dutch, Hungarian.
* Tue Sep  4 2018 mvetter@suse.com
- Update to 1.6.16:
  * FIXED: Could not always save to remote drives.
  * FIXED: Could not browse shortcuts in Windows file dialogs.
* Mon Jul 23 2018 mvetter@suse.com
- Update to 1.6.15:
  * FIXED: Automatic high dpi support.
  * Translation updates: Galician, Spanish.
* Mon Jul 16 2018 mvetter@suse.com
- Update to 1.6.14:
  * FIXED: Regression where emergency cache didn't run.
  * Renamed NEWS to ChangeLog.
  * Translation updates: Bosnian.
* Tue May 29 2018 mvetter@suse.com
- Update to 1.6.13:
  * Updated dictionaries.
  * Updated Unicode symbols database.
  * Replaced deprecated code.
  * Extra warnings only shown in debug build.
  * Translation updates: Dutch, French, Portuguese.
* Sun Apr 15 2018 mvetter@suse.com
- Update to 1.6.12:
  * Ignore empty cache files.
  * Remove auto save.
  * Translation updates: Slovenian.
* Sat Mar 31 2018 mvetter@suse.com
- Update to 1.6.11:
  * FIXED: File monitoring prevented saving in Windows.
  * Translation updates: Danish, Slovenian.
* Mon Feb 26 2018 mvetter@suse.com
- Update to version 1.6.10:
  * Default to Flat ODT for cache files.
  * Reduce time between cache writes to 5 minutes.
  * FIXED: Fade effect broke alerts.
  * FIXED: Fade effect hid text on load screen.
  * Translation updates: Greek.
* Mon Jan  8 2018 mpluskal@suse.com
- Update to version 1.6.8:
  * FIXED: Could not compile with Qt 5.10.
  * FIXED: Did not handle ODT line position with two values.
  * Translation updates: German, Indonesian.
- Do not run post scriplets on Tumbleweed where they are not needed
* Thu Oct 19 2017 mpluskal@suse.com
- Update to version 1.6.7:
  * Updated dictionaries.
  * FIXED: HiDPI blurred text backgrounds were scaled.
  * FIXED: Window margin was always the size of the scrollbar.
  * FIXED: Always indented first line when printing.
- Changes for version 1.6.6:
  * FIXED: Did not always install translations in Linux.
  * FIXED: Unneccessary compiler warning about switch fallthrough.
  * FIXED: Did not show headings when automatic spellchecking was disabled.
  * FIXED: Foreground incorrectly placed when load stretched themes.
  * Translation updates: Czech, Armenian.
* Thu Jun 22 2017 mpluskal@suse.com
- Update to version 1.6.5:
  * FIXED: Data loss when program crashed.
  * Updated included hunspell.
  * Updated dictionaries.
  * Translation updates: Greek, Swedish.
* Thu Apr 27 2017 dsterba@suse.cz
- update to version 1.6.4:
  * Updated AppData installation directory.
  * FIXED: HiDPI blurred text backgrounds were offset and scaled.
  * FIXED: HiDPI backgrounds were not centered properly.
  * FIXED: HiDPI centered backgrounds were also scaled.
  * Translation updates: Chinese (Taiwan), Finnish, German, Indonesian.
* Tue Feb 28 2017 mpluskal@suse.com
- Split lang subpackage
* Fri Dec 23 2016 mpluskal@suse.com
- Update to version 1.6.3:
  * Updated included hunspell.
  * FIXED: Line spacing was ignored when pasting in new documents.
  * FIXED: Pasting text always made document rich text.
  * FIXED: Possible delay on start when creating non-native printer.
  * Translation updates: Chinese (China), Japanese, Korean, Lithuanian, Polish, Russian, Ukrainian.
- Changes for version 1.6.2:
  * Generate binary translations at build time.
  * FIXED: Focused text did not handle first-line indent.
  * FIXED: Was not properly loading Qt translations.
  * Translation updates: Armenian, Dutch, Italian, Lithuanian, Portuguese (Brazil), Romanian, Swedish, Ukrainian.
- Changes for version 1.6.1:
  * FIXED: Incorrectly handled non-heading text in OOXML.
  * FIXED: Misspelled words did not follow heading style.
  * FIXED: Did not always close OOXML paragraph properties correctly.
  * FIXED: Did not correctly store RTL in OOXML.
  * FIXED: Reported conflicts for empty shortcuts.
  * FIXED: Switched to incorrect tab to show conflicting shortcuts.
  * Translation updates: German, Romanian.
* Sun Sep 11 2016 mpluskal@suse.com
- Update to version 1.6.0:
  * Added always showing interface
  * Added headings
  * Added new default themes
  * Added removing user-installed dictionaries
  * Added shortcut for typographical apostrophe
  * Added support for ODT Flat XML files
  * Added support for high DPI displays
  * Switched to QSoundEffect
  * Updated dictionaries
  * FIXED: Daily progress did not reset when run longer than a day
  * FIXED: Printer margins were too big
  * FIXED: Was replacing session files with command-line files
  * FIXED: Did not add new default symbol shortcuts
  * Translation updates
- Changes for version 1.5.7:
  * Switched to cross-compiled builds for Windows
  * FIXED: Did not play sounds for key presses with Alt modifier
  * FIXED: Could not change shortcut to disable focused text
- Changes for version 1.5.6:
  * Updated included hunspell
  * FIXED: Did not remember some default formats
  * FIXED: Replace all did not update spellchecking
  * FIXED: Themes still did not always forget changes
  * Translation updates
* Tue May  3 2016 mpluskal@suse.com
- Cleanup spec file
  * use pkgconfig style dependencies
  * drop non openSUSE conditionals
  * use qmake5 macro
- Use url for source
* Mon Sep  7 2015 dsterba@suse.cz
- version 1.5.5
  * Added support for pasting RTF in Windows
  * Switched back to dynamic builds for Windows
  * Updated dictionaries
  * FIXED: Themes did not always forget changes
  * FIXED: Treated every paragraph as a scene when divider is empty
  * FIXED: Switched tabs during autosave
  * FIXED: Allowed pasting and saving invalid null character
  * Translation updates: Catalan, Esperanto, Lithuanian, Portuguese (Brazil)
* Sun Aug 30 2015 dsterba@suse.cz
- initial import to editors, version 1.5.4
  - minor cleanups in spec file
  - old changes file renamed
